@@ -7,7 +7,7 @@ import safrs
 from .jsonapi import paginate, jsonapi_sort
 from .json_encoder import SAFRSFormattedResponse
 from .swagger_doc import jsonapi_rpc
-from .errors import GenericError, ValidationError
+from .errors import GenericError, SystemValidationError
 
 
 @jsonapi_rpc(http_methods=["POST"])
@@ -38,7 +38,7 @@ def lookup_re_mysql(cls, **kwargs):  # pragma: no cover
     for key, value in kwargs.items():
         column = getattr(cls, key, None)
         if not column:
-            raise ValidationError('Invalid Column "{}"'.format(key))
+            raise SystemValidationError('Invalid Column "{}"'.format(key))
         try:
             result = result.query.filter(column.op("regexp")(value))
         except Exception as exc:
@@ -71,7 +71,7 @@ def startswith(cls, **kwargs):  # pragma: no cover
     for key, value in kwargs.items():
         column = getattr(cls, key, None)
         if not column:
-            raise ValidationError('Invalid Column "{}"'.format(key))
+            raise SystemValidationError('Invalid Column "{}"'.format(key))
         try:
             instances = result.query.filter(column.like(value + "%"))
             links, instances, count = paginate(instances)
@@ -95,11 +95,12 @@ def search(cls, **kwargs):  # pragma: no cover
         col_name: value
     """
     query = kwargs.get("query", "")
+    columns = [c for c in cls._s_columns if c.type.python_type in [str, int, float]]
     if ":" in query:
         column_name, value = query.split(":")
-        result = cls.query.filter(or_(column.like("%" + value + "%") for column in cls._s_columns if column.name == column_name))
+        result = cls.query.filter(or_(column.like("%" + value + "%") for column in columns if column.name == column_name))
     else:
-        result = cls.query.filter(or_(column.like("%" + query + "%") for column in cls._s_columns))
+        result = cls.query.filter(or_(column.like("%" + query + "%") for column in columns))
     instances = jsonapi_sort(result, cls)
     links, instances, count = paginate(instances)
     data = [item for item in instances]
